searchData={"items":[{"type":"task","title":"mix tableau.build","doc":"Task to build the tableau site","ref":"Mix.Tasks.Tableau.Build.html"},{"type":"task","title":"mix tableau.server","doc":"Starts the tableau dev server","ref":"Mix.Tasks.Tableau.Server.html"},{"type":"module","title":"Tableau","doc":"","ref":"Tableau.html"},{"type":"module","title":"Global Site Configuration - Tableau","doc":"* `:include_dir` - string - Directory that is just copied to the output directory. Defaults to `extra`.\n* `:timezone` - string - Timezone to use when parsing date times. Defaults to `Etc/UTC`.\n* `:base_path` - string - Development server root.  Defaults to '/'.\n* `:url` - string (required) - The URL of your website.\n* `:converters` - mapping of file extensions to converter module. Defaults to `[md: Tableau.MDExConverter]`\n* `:markdown` - keyword\n    * `:mdex` - keyword - Options to pass to `MDEx.to_html/2`","ref":"Tableau.html#module-global-site-configuration"},{"type":"module","title":"Example - Tableau","doc":"```elixir\n# configs/config.exs\nconfig :tableau, :config,\n  url: \"http://localhost:8080\",\n  timezone: \"America/Indiana/Indianapolis\",\n  converters: [\n    md: Tableau.MDExConverter,\n    dj: MySite.DjotConverter\n  ],\n  markdown: [\n    mdex: [\n      extension: [table: true, header_ids: \"\", tasklist: true, strikethrough: true],\n      render: [unsafe_: true],\n      features: [syntax_highlight_theme: \"kanagawa\"]\n    ]\n  ]\n```","ref":"Tableau.html#module-example"},{"type":"function","title":"Tableau.live_reload/1","doc":"Component to connect to the development server via websocket to broadcast that the page should reload.\n\nBy default, connects to `'ws://' + location.host + '/ws'`.\n\nSee `WebDevUtils` for configuration options.","ref":"Tableau.html#live_reload/1"},{"type":"function","title":"Tableau.markdown/2","doc":"Convert markdown content to HTML using `MDEx.to_html!/2`.\n\nWill use the globally configured options, but you can also pass it overrides.","ref":"Tableau.html#markdown/2"},{"type":"module","title":"Tableau.Document.Helper","doc":"Helper functions for Tableau documents.","ref":"Tableau.Document.Helper.html"},{"type":"macro","title":"Tableau.Document.Helper.render/1","doc":"A macro for rendering nested content within a layout.\n\nPlease see the `Tableau.Layout` docs for more info.","ref":"Tableau.Document.Helper.html#render/1"},{"type":"behaviour","title":"Tableau.Layout","doc":"A tableau layout.\n\nLayouts will render `@inner_content` using the `Tableau.Document.Helper.render/1` macro.\n\n```elixir\ndefmodule MySite.SidebarLayout do\n  use Tableau.Page,\n    layout: MySite.RootLayout\n\n  def template(assigns) do\n    \"\"\"\n     \n       \n       \n     \n\n     \n      <%= render @inner_content %>\n     \n    \"\"\"\n  end\nend\n```","ref":"Tableau.Layout.html"},{"type":"callback","title":"Tableau.Layout.template/1","doc":"The layout template.","ref":"Tableau.Layout.html#c:template/1"},{"type":"type","title":"Tableau.Layout.assigns/0","doc":"","ref":"Tableau.Layout.html#t:assigns/0"},{"type":"type","title":"Tableau.Layout.template/0","doc":"","ref":"Tableau.Layout.html#t:template/0"},{"type":"behaviour","title":"Tableau.Page","doc":"A tableau page.\n\nA page is a basic unit of a static site.\n\n```elixir\ndefmodule MySite.HomePage do\n  use Tableau.Page,\n    layout: MySite.RootLayout,\n    permalink: \"/\"\n\n  def template(assigns) do\n    \"\"\"\n     My Site \n\n     \n      Welcome to my site!\n     \n    \"\"\"\n  end\nend\n```","ref":"Tableau.Page.html"},{"type":"function","title":"Tableau.Page.__struct__/0","doc":"The page struct allows you to create pages as data structures and manually insert them into the Graph.","ref":"Tableau.Page.html#__struct__/0"},{"type":"callback","title":"Tableau.Page.template/1","doc":"The page template.","ref":"Tableau.Page.html#c:template/1"},{"type":"type","title":"Tableau.Page.assigns/0","doc":"","ref":"Tableau.Page.html#t:assigns/0"},{"type":"type","title":"Tableau.Page.template/0","doc":"","ref":"Tableau.Page.html#t:template/0"},{"type":"behaviour","title":"Tableau.Converter","doc":"Defines the interface for the converter module used by extensions to parse markup files.","ref":"Tableau.Converter.html"},{"type":"callback","title":"Tableau.Converter.convert/4","doc":"Converts content into HTML.\n\nIs given the file path, the content of the files (sans front matter), the front matter, and a list of options.","ref":"Tableau.Converter.html#c:convert/4"},{"type":"module","title":"Tableau.MDExConverter","doc":"Converter to parse markdown content with `MDEx`","ref":"Tableau.MDExConverter.html"},{"type":"function","title":"Tableau.MDExConverter.convert/4","doc":"","ref":"Tableau.MDExConverter.html#convert/4"},{"type":"module","title":"Tableau.DataExtension","doc":"YAML files and Elixir scripts (.exs) in the configured directory will be automatically parsed/executed and made available in an `@data` assign in your templates.\n\nElixir scripts will be executed and the last expression returned as the data.","ref":"Tableau.DataExtension.html"},{"type":"module","title":"Configuration - Tableau.DataExtension","doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for data files. Defaults to `_data`","ref":"Tableau.DataExtension.html#module-configuration"},{"type":"module","title":"Example - Tableau.DataExtension","doc":"```elixir\nconfig :tableau, Tableau.DataExtension,\n  enabled: true,\n  dir: \"_facts\"\n```\n\n<!-- tabs-open -->","ref":"Tableau.DataExtension.html#module-example"},{"type":"module","title":"YAML - Tableau.DataExtension","doc":"```yaml\n# _facts/homies.yaml\n- name: Mitch\n- name: Jimbo\n- name: Bobby\n```\n\n```heex\n \n   \n    <%= homie.name %>\n   \n \n```","ref":"Tableau.DataExtension.html#module-yaml"},{"type":"module","title":"Elixir - Tableau.DataExtension","doc":"```elixir\n# _facts/homies.exs\nresp = Req.get!(\"https://example.com/homies\")\n\nresp.body[\"homies\"]\n```\n\n```heex\n \n   \n    <%= homie.name %>\n   \n \n```\n\n<!-- tabs-close -->","ref":"Tableau.DataExtension.html#module-elixir"},{"type":"function","title":"Tableau.DataExtension.config/1","doc":"","ref":"Tableau.DataExtension.html#config/1"},{"type":"function","title":"Tableau.DataExtension.run/1","doc":"","ref":"Tableau.DataExtension.html#run/1"},{"type":"behaviour","title":"Tableau.Extension","doc":"A tableau extension.\n\nAn extension can be used to generate other kinds of content.","ref":"Tableau.Extension.html"},{"type":"behaviour","title":"Options - Tableau.Extension","doc":"* `:key` - The key in which the extensions configuration and data is loaded.\n* `:type` - The type of extension. See below for a description.\n* `:priority` - An integer used for ordering extensions of the same type.\n* `:enabled` - Whether or not to enable the extension. Defaults to true, and can be configured differently based on the extension.","ref":"Tableau.Extension.html#module-options"},{"type":"behaviour","title":"Types - Tableau.Extension","doc":"There are currently the following extension types:\n\n- `:pre_build` - executed before tableau builds your site and writes anything to disk.\n- `:pre_write` - executed after tableau builds your site but before it writes anything to disk.\n- `:post_write` - executed after tableau builds your site and writes everything to disk.","ref":"Tableau.Extension.html#module-types"},{"type":"behaviour","title":"The Graph - Tableau.Extension","doc":"Tableau pages and layouts form a DAG, a Directed Acyclic Graph, and this graph is used to build each page when writing to disk.\n\nYour extension can create data to insert into the site token and can also inserted pages into the graph to be written to disk when the time comes.","ref":"Tableau.Extension.html#module-the-graph"},{"type":"behaviour","title":"Example - Tableau.Extension","doc":"In this example, we create a simple post extension that reads markdown files from disk, inserts them into the graph, and inserts them into the token.\n\nBy inserting them into the token, you are able to access them inside your templates, for example, a posts listing page.\n\n```elixir\ndefmodule MySite.PostsExtension do\n  use Tableau.Extension, key: :posts, type: :pre_build, priority: 300\n\n  def run(token) do\n    posts = \n      for post <- Path.wildcard(\"_posts/**/*.md\") do\n        %Tableau.Page{\n          parent: MySite.RootLayout,\n          permalink: Path.join(\"posts\", Path.rootname(post)),\n          template: Markdown.render(post),\n          opts: %{}\n        }\n      end\n\n    graph = Tableau.Graph.insert(token.graph, posts)\n\n    {:ok,\n     token\n     |> Map.put(:posts, posts)\n     |> Map.put(:graph, graph)}\n  end\nend\n```","ref":"Tableau.Extension.html#module-example"},{"type":"callback","title":"Tableau.Extension.config/1","doc":"Optional callback to validate the config for an extension. Useful for \nproviding more useful error messages for misconfigurations.","ref":"Tableau.Extension.html#c:config/1"},{"type":"callback","title":"Tableau.Extension.run/1","doc":"The extension entry point.\n\nThe function is passed a token and can return a new token with new data loaded into it.","ref":"Tableau.Extension.html#c:run/1"},{"type":"type","title":"Tableau.Extension.token/0","doc":"","ref":"Tableau.Extension.html#t:token/0"},{"type":"module","title":"Tableau.PageExtension","doc":"Content files (with YAML frontmatter) in the configured pages directory will be automatically compiled into Tableau pages.\n\nCertain frontmatter keys are required and all keys are passed as options to the `Tableau.Page`.","ref":"Tableau.PageExtension.html"},{"type":"module","title":"Options - Tableau.PageExtension","doc":"Frontmatter is compiled with `yaml_elixir` and all keys are converted to atoms.\n\n* `:title` - The title of the page\n* `:permalink` - The permalink of the page.\n* `:layout` - A string representation of a Tableau layout module.\n* `:converter` - A string representation of a converter module. (optional)","ref":"Tableau.PageExtension.html#module-options"},{"type":"module","title":"Example - Tableau.PageExtension","doc":"```yaml\nid: \"GettingStarted\"\ntitle: \"Getting Started\"\npermalink: \"/docs/:title\"\nlayout: \"ElixirTools.PageLayout\"\nconverter: \"MyConverter\"\n```","ref":"Tableau.PageExtension.html#module-example"},{"type":"module","title":"Permalink - Tableau.PageExtension","doc":"The permalink is a string with colon prefixed template variables.\n\nThese variables will be swapped with the corresponding YAML Frontmatter key, with the result being piped through `to_string/1`.","ref":"Tableau.PageExtension.html#module-permalink"},{"type":"module","title":"Configuration - Tableau.PageExtension","doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for markdown files. Defaults to `_pages`\n- `:permalink` - string - Default output path for pages. Accepts `:title` as a replacement keyword, replaced with the page's provided title. If a page has a `:permalink` provided, that will override this value _for that page_.\n- `:layout` - string - Elixir module providing page layout for pages. Default is nil.","ref":"Tableau.PageExtension.html#module-configuration"},{"type":"module","title":"Example - Tableau.PageExtension","doc":"```elixir\nconfig :tableau, Tableau.PageExtension,\n  enabled: true,\n  dir: \"_docs\",\n  permalink: \"/docs/:title\",\n  layout: \"MyApp.PageLayout\"\n```","ref":"Tableau.PageExtension.html#module-example"},{"type":"module","title":"Content formats - Tableau.PageExtension","doc":"If you're interested in authoring your content in something other than markdown (or you want to use a different markdown parser), you can configure\na converter for your format in the global configuration.\n\nCurrently the `Tableau.MDExConverter` is the only builtin converter, but you are free to write your own!\n\n```elixir\n# configs/config.exs\nconfig :tableau, :config,\n  converters: [\n    md: Tableau.MDExConverter,\n    adoc: MySite.AsciiDocConverter\n  ],\n```\n\nAs noted above, a converter can be overridden on a specific page, using the frontmatter `:converter` key.","ref":"Tableau.PageExtension.html#module-content-formats"},{"type":"function","title":"Tableau.PageExtension.config/1","doc":"","ref":"Tableau.PageExtension.html#config/1"},{"type":"function","title":"Tableau.PageExtension.run/1","doc":"","ref":"Tableau.PageExtension.html#run/1"},{"type":"module","title":"Tableau.PostExtension","doc":"Content files (with YAML frontmatter) in the configured posts directory will be automatically compiled into Tableau pages.\n\nCertain frontmatter keys are required and all keys are passed as options to the `Tableau.Page`.","ref":"Tableau.PostExtension.html"},{"type":"module","title":"Options - Tableau.PostExtension","doc":"Frontmatter is compiled with `yaml_elixir` and all keys are converted to atoms.\n\n* `:title` - The title of the post.\n* `:permalink` - The permalink of the post. `:title` will be replaced with the posts title and non alphanumeric characters removed. Optional.\n* `:date` - A string representation of an Elixir `NaiveDateTime`, often presented as a `sigil_N`. This will be converted to your configured timezone.\n* `:layout` - A string representation of a Tableau layout module.\n* `:converter` - A string representation of a converter module. (optional)","ref":"Tableau.PostExtension.html#module-options"},{"type":"module","title":"Example - Tableau.PostExtension","doc":"```yaml\nid: \"Update.Volume3\"\ntitle: \"The elixir-tools Update Vol. 3\"\npermalink: \"/news/:title\"\ndate: \"~N[2023-09-19 01:00:00]\"\nlayout: \"ElixirTools.PostLayout\"\nconverter: \"MyConverter\"\n```","ref":"Tableau.PostExtension.html#module-example"},{"type":"module","title":"Permalink - Tableau.PostExtension","doc":"The permalink is a string with colon prefixed template variables.\n\nThese variables will be swapped with the corresponding YAML Frontmatter key, with the result being piped through `to_string/1`.\n\nIn addition, there are `:year`, `:month`, and `:day` template variables.","ref":"Tableau.PostExtension.html#module-permalink"},{"type":"module","title":"Configuration - Tableau.PostExtension","doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for markdown files. Defaults to `_posts`\n- `:future` - boolean - Show posts that have dates later than the current timestamp, or time at which the site is generated.\n- `:permalink` - string - Default output path for posts. Accepts `:title` as a replacement keyword, replaced with the post's provided title. If a post has a `:permalink` provided, that will override this value _for that post_.\n- `:layout` - string - Elixir module providing page layout for posts. Default is nil","ref":"Tableau.PostExtension.html#module-configuration"},{"type":"module","title":"Example - Tableau.PostExtension","doc":"```elixir\nconfig :tableau, Tableau.PostExtension,\n  enabled: true,\n  dir: \"_articles\",\n  future: true,\n  permalink: \"/articles/:year/:month/:day/:title\",\n  layout: \"MyApp.PostLayout\"\n```","ref":"Tableau.PostExtension.html#module-example"},{"type":"module","title":"Content formats - Tableau.PostExtension","doc":"If you're interested in authoring your content in something other than markdown (or you want to use a different markdown parser), you can configure\na converter for your format in the global configuration.\n\nCurrently the `Tableau.MDExConverter` is the only builtin converter, but you are free to write your own!\n\n```elixir\n# configs/config.exs\nconfig :tableau, :config,\n  converters: [\n    md: Tableau.MDExConverter,\n    adoc: MySite.AsciiDocConverter\n  ],\n```\n\nAs noted above, a converter can be overridden on a specific page, using the frontmatter `:converter` key.","ref":"Tableau.PostExtension.html#module-content-formats"},{"type":"module","title":"Tableau.RSSExtension","doc":"Generate RSS data and write to `_site/feed.xml`.","ref":"Tableau.RSSExtension.html"},{"type":"module","title":"Configuration - Tableau.RSSExtension","doc":"- `:enabled` - boolean - Extension is active or not.\n- `:title` - string (required) - Title of your feed.\n- `:description` - string (required) - Description of your feed.\n- `:language` - string - Language to use in the ` ` tag. Defaults to \"en-us\"","ref":"Tableau.RSSExtension.html#module-configuration"},{"type":"module","title":"Example - Tableau.RSSExtension","doc":"```elixir\nconfig :tableau, Tableau.RSSExtension,\n  enabled: true,\n  language: \"pt-BR\",\n  title: \"My Elixir Devlog\",\n  description: \"My Journey on Becoming the Best Elixirist\"\n```","ref":"Tableau.RSSExtension.html#module-example"},{"type":"function","title":"Tableau.RSSExtension.config/1","doc":"","ref":"Tableau.RSSExtension.html#config/1"},{"type":"function","title":"Tableau.RSSExtension.run/1","doc":"","ref":"Tableau.RSSExtension.html#run/1"},{"type":"module","title":"Tableau.SitemapExtension","doc":"Generate a sitemap.xml for your site, for improved search-engine indexing.","ref":"Tableau.SitemapExtension.html"},{"type":"module","title":"Configuration - Tableau.SitemapExtension","doc":"- `:enabled` - boolean - Extension is active or not.","ref":"Tableau.SitemapExtension.html#module-configuration"},{"type":"module","title":"Example - Tableau.SitemapExtension","doc":"```elixir\nconfig :tableau, Tableau.SitemapExtension,\n  enabled: true,\n```","ref":"Tableau.SitemapExtension.html#module-example"},{"type":"module","title":"Custom attributes - Tableau.SitemapExtension","doc":"Any page may add attributes to its sitemap ` ` entry by adding a `sitemap` entry, with a map of elements to add","ref":"Tableau.SitemapExtension.html#module-custom-attributes"},{"type":"module","title":"Frontmatter - Tableau.SitemapExtension","doc":"```yaml\ntitle: \"Some Page\"\nsitemap:\n  priority: 0.8\n  changefreq: hourly\n```","ref":"Tableau.SitemapExtension.html#module-frontmatter"},{"type":"module","title":"Tableau.Page - Tableau.SitemapExtension","doc":"```elixir\ndefmodule MySite.AboutPage do\n  use Tableau.Page,\n    layout: MySite.RootLayout,\n    permalink: \"/about\",\n    sitemap: %{priority: 0.8, changefreq: \"monthly\"}\n\n  # ...\nend\n```\n\nGenerated sitemap is stored in the root of your site, at /sitemap.xml.\n\nFor more information about sitemaps, see  .","ref":"Tableau.SitemapExtension.html#module-tableau-page"},{"type":"function","title":"Tableau.SitemapExtension.run/1","doc":"","ref":"Tableau.SitemapExtension.html#run/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}